.. toctree::
    :maxdepth: 2
    :caption: API Documentation

    api/q1ss
    api/q1ss.ap
    api/q1ss.ap.base
    api/q1ss.ap.explicit
    api/q1ss.ap.generated
    api/q1ss.ap.sequence
    api/q1ss.ap.vectorized
    api/q1ss.binalg
    api/q1ss.binalg.affine
    api/q1ss.binalg.base
    api/q1ss.binalg.binmat
    api/q1ss.binalg.binvec
    api/q1ss.binalg.vectorized
    api/q1ss.utils
    api/q1ss.utils.options
